# SciDirectTrends

![PyPI](https://img.shields.io/pypi/v/SciDirectTrends?style=for-the-badge)
[![MIT License](https://img.shields.io/badge/License-MIT-yellow.svg?style=for-the-badge)](https://github.com/AliRezaBeigy/SciDirectTrends/blob/master/LICENSE)
[![PR's Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=for-the-badge)](http://makeapullrequest.com)
![GitHub Repo stars](https://img.shields.io/github/stars/AliRezaBeigy/SciDirectTrends?style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dm/SciDirectTrends?style=for-the-badge)

A tool for fetching and visualizing publication trends from ScienceDirect.

<p align="center">
  <img width="1350" src="https://raw.githubusercontent.com/AliRezaBeigy/SciDirectTrends/main/sample/trend.png">
</p>

## Requirements

- Python 3.6 or higher
- Access to ScienceDirect

## Quick Start

First, ensure Python 3.6+ is installed on your system. You can download Python from the [Official Python Website](https://www.python.org/downloads).

To install SciDirectTrends:

```shell
$ pip install -U SciDirectTrends
```
Use -U to update SciDirectTrends to the latest version

## Usage
Basic command to visualize publication trends:
```shell
$ scidirecttrends --query "your query here"
```
Customize the visualization:
```shell
$ scidirecttrends --title "Custom Title" --query "your query here" --output "trend.png"
```


## Features
Fetches publication data from ScienceDirect based on a user-defined query.
Generates visualizations of publication trends over time.
Customizable visualization titles and output formats.

## Contributions
Contributions to SciDirectTrends are highly appreciated. If you're interested in contributing, feel free to fork the repository, make changes, and create a pull request.

If you need help or have suggestions, please contact me:

Email: alireza.beigy.rb@gmail.com
Telegram: @AliRezaBeigy

## License
This project is licensed under the MIT License - see the LICENSE file for details.